@@ -7,6 +7,6 @@ class Bikes:
     def __inti__(self):
         pass
 
-    async def get_bikes(self) -> List[Bike]:
-        bikes = await Api.get_bikes()
+    def get_bikes(self) -> List[Bike]:
+        bikes = Api.get_bikes()
         return [Bike(bike_data) for bike_data in bikes]
\ No newline at end of file
