@@ -7,13 +7,13 @@ class Stations:
     def __init__(self):
         self.stations = []
 
-    async def get_stations(self):
-        stations = [Station(sation) for sation in await Api.get_stations()]
+    def get_stations(self):
+        stations = [Station(sation) for sation in Api.get_stations()]
         return stations
 
-    async def get_station(self, stationNumber: int) -> Station:
+    def get_station(self, stationNumber: int) -> Station:
 
-        station_data =  await Api.get_station(stationNumber)
+        station_data = Api.get_station(stationNumber)
         station = Station(station_data)
         return station
 
