@@ -9,5 +9,5 @@ class Velov:
         self.stations: Stations = Stations()
         self.bikes: Bikes = Bikes()
 
-    async def start(self):
-        await Api.set_tokens()
+    def start(self):
+        Api.set_tokens()
